searchData={"items":[{"type":"module","title":"OrderedCollections","doc":"OrderedCollections provides sorted data structures for Elixir,\nincluding a `SortedMap` and (eventually) a `SortedSet`.","ref":"OrderedCollections.html"},{"type":"module","title":"Modules - OrderedCollections","doc":"- `OrderedCollections.SortedMap` - A sorted key-value store implemented using Erlang's `:gb_trees`.\n  - `OrderedCollections.SortedSet` - A sorted set implemented using Erlang's `:gb_sets`.","ref":"OrderedCollections.html#module-modules"},{"type":"module","title":"Examples - OrderedCollections","doc":"iex> sm = OrderedCollections.SortedMap.new(%{b: 2, a: 1})\n    iex> OrderedCollections.SortedMap.get(sm, :a)\n    1\n\nYou can also use convenience functions:\n\n    iex> sm = OrderedCollections.new_map(%{x: 10})\n    iex> sm = OrderedCollections.put_map(sm, :y, 20)\n    iex> OrderedCollections.get_map(sm, :y)\n    20","ref":"OrderedCollections.html#module-examples"},{"type":"function","title":"OrderedCollections.get_map/3","doc":"Retrieves the value for the given key from a SortedMap, returning a default if the key is missing.","ref":"OrderedCollections.html#get_map/3"},{"type":"function","title":"OrderedCollections.new_map/0","doc":"Creates a new empty SortedMap.","ref":"OrderedCollections.html#new_map/0"},{"type":"function","title":"Examples - OrderedCollections.new_map/0","doc":"iex> sm = OrderedCollections.new_map()\n  iex> OrderedCollections.to_map(sm)\n  %{}","ref":"OrderedCollections.html#new_map/0-examples"},{"type":"function","title":"OrderedCollections.new_map/1","doc":"Creates a new SortedMap from a regular map.","ref":"OrderedCollections.html#new_map/1"},{"type":"function","title":"Examples - OrderedCollections.new_map/1","doc":"iex> m = %{b: 2, a: 1}\n  iex> sm = OrderedCollections.new_map(m)\n  iex> OrderedCollections.get_map(sm, :a)\n  1","ref":"OrderedCollections.html#new_map/1-examples"},{"type":"function","title":"OrderedCollections.put_map/3","doc":"Inserts a key-value pair into a SortedMap.","ref":"OrderedCollections.html#put_map/3"},{"type":"function","title":"OrderedCollections.to_map/1","doc":"Creates a map from a SortedMap.","ref":"OrderedCollections.html#to_map/1"},{"type":"function","title":"Examples - OrderedCollections.to_map/1","doc":"iex> sm = OrderedCollections.new_map(%{b: 2, a: 1})\n  iex> OrderedCollections.to_map(sm)\n  %{a: 1, b: 2}","ref":"OrderedCollections.html#to_map/1-examples"},{"type":"module","title":"OrderedCollections.SortedMap","doc":"A sorted key-value store implemented using Erlang's `:gb_trees` (Red-Black Trees).\n\nThis module stores items in sorted order by their keys.","ref":"OrderedCollections.SortedMap.html"},{"type":"function","title":"OrderedCollections.SortedMap.delete/2","doc":"Deletes a key.","ref":"OrderedCollections.SortedMap.html#delete/2"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.delete/2","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> sm2 = SortedMap.delete(sm, :b)\n    iex> SortedMap.has_key?(sm2, :b)\n    false","ref":"OrderedCollections.SortedMap.html#delete/2-examples"},{"type":"function","title":"OrderedCollections.SortedMap.get/3","doc":"Retrieves a value by key, returning a default if missing.","ref":"OrderedCollections.SortedMap.html#get/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.get/3","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> SortedMap.get(sm, :a)\n    1\n    iex> SortedMap.get(sm, :b, :default)\n    :default","ref":"OrderedCollections.SortedMap.html#get/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.has_key?/2","doc":"Checks if a key exists.","ref":"OrderedCollections.SortedMap.html#has_key?/2"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.has_key?/2","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> SortedMap.has_key?(sm, :a)\n    true\n    iex> SortedMap.has_key?(sm, :c)\n    false","ref":"OrderedCollections.SortedMap.html#has_key?/2-examples"},{"type":"function","title":"OrderedCollections.SortedMap.max_key/1","doc":"Returns the largest key. Returns `:none` if the map is empty.","ref":"OrderedCollections.SortedMap.html#max_key/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.max_key/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1, c: 3})\n    iex> SortedMap.max_key(sm)\n    :c\n\n    iex> sm_empty = SortedMap.new()\n    iex> SortedMap.max_key(sm_empty)\n    :none","ref":"OrderedCollections.SortedMap.html#max_key/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.min_key/1","doc":"Returns the smallest key. Returns `:none` if the map is empty.","ref":"OrderedCollections.SortedMap.html#min_key/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.min_key/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1, c: 3})\n    iex> SortedMap.min_key(sm)\n    :a\n\n    iex> sm_empty = SortedMap.new()\n    iex> SortedMap.min_key(sm_empty)\n    :none","ref":"OrderedCollections.SortedMap.html#min_key/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.new/0","doc":"Creates a new empty sorted map.","ref":"OrderedCollections.SortedMap.html#new/0"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.new/0","doc":"iex> sm = SortedMap.new()\n    iex> SortedMap.to_map(sm)\n    %{}","ref":"OrderedCollections.SortedMap.html#new/0-examples"},{"type":"function","title":"OrderedCollections.SortedMap.new/1","doc":"Creates a new sorted map from a standard map.","ref":"OrderedCollections.SortedMap.html#new/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.new/1","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> SortedMap.get(sm, :a)\n    1\n    iex> SortedMap.get(sm, :b)\n    2","ref":"OrderedCollections.SortedMap.html#new/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.put/3","doc":"Inserts a key-value pair, maintaining order.","ref":"OrderedCollections.SortedMap.html#put/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.put/3","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> sm = SortedMap.put(sm, :b, 2)\n    iex> SortedMap.get(sm, :b)\n    2","ref":"OrderedCollections.SortedMap.html#put/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.range/3","doc":"Iterates over a range of keys, returning key-value pairs\nwhose keys are between `min` and `max` (inclusive).","ref":"OrderedCollections.SortedMap.html#range/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.range/3","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2, c: 3, d: 4})\n    iex> SortedMap.range(sm, :b, :c)\n    [{:b, 2}, {:c, 3}]","ref":"OrderedCollections.SortedMap.html#range/3-examples"},{"type":"type","title":"OrderedCollections.SortedMap.t/0","doc":"","ref":"OrderedCollections.SortedMap.html#t:t/0"},{"type":"function","title":"OrderedCollections.SortedMap.to_list/1","doc":"Returns all key-value pairs in sorted order.","ref":"OrderedCollections.SortedMap.html#to_list/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.to_list/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1})\n    iex> SortedMap.to_list(sm)\n    [{:a, 1}, {:b, 2}]","ref":"OrderedCollections.SortedMap.html#to_list/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.to_map/1","doc":"Converts the `SortedMap` into a standard `Map`, losing the sorted property.","ref":"OrderedCollections.SortedMap.html#to_map/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.to_map/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1})\n    iex> SortedMap.to_map(sm)\n    %{a: 1, b: 2}","ref":"OrderedCollections.SortedMap.html#to_map/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.update/3","doc":"Updates a key with a function. If the key doesn’t exist,\nit is set to `nil`.","ref":"OrderedCollections.SortedMap.html#update/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.update/3","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> sm = SortedMap.update(sm, :a, &(&1 + 1))\n    iex> SortedMap.get(sm, :a)\n    2\n\n    iex> SortedMap.new(%{a: 1}) |> SortedMap.update(:b, &(&1 + 1)) |> SortedMap.get(:b)\n    nil","ref":"OrderedCollections.SortedMap.html#update/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.update/4","doc":"Updates a key with a function. If the key doesn’t exist,\nit sets it to `default`.","ref":"OrderedCollections.SortedMap.html#update/4"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.update/4","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> sm = SortedMap.update(sm, :a, &(&1 + 5), 0)\n    iex> SortedMap.get(sm, :a)\n    6\n\n    iex> SortedMap.new(%{a: 1}) |> SortedMap.update(:b, &(&1 + 1), 10) |> SortedMap.get(:b)\n    10","ref":"OrderedCollections.SortedMap.html#update/4-examples"},{"type":"function","title":"OrderedCollections.SortedMap.update_with_value/3","doc":"Replaces the value for `key` with `new_value` if the key exists.\nIf `key` does not exist, the map remains unchanged.","ref":"OrderedCollections.SortedMap.html#update_with_value/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.update_with_value/3","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> sm = SortedMap.update_with_value(sm, :a, 100)\n    iex> SortedMap.get(sm, :a)\n    100\n    iex> SortedMap.update_with_value(sm, :c, 300)\n    iex> SortedMap.get(sm, :c)\n    nil","ref":"OrderedCollections.SortedMap.html#update_with_value/3-examples"},{"type":"module","title":"OrderedCollections.SortedSet","doc":"A sorted set implemented using Erlang's `:gb_sets`.\n\nThis module provides a sorted set data structure with efficient insertions,\ndeletions, and membership checks. Internally it wraps Erlang's `:gb_sets`\nto maintain elements in sorted order.","ref":"OrderedCollections.SortedSet.html"},{"type":"module","title":"Examples - OrderedCollections.SortedSet","doc":"iex> set = OrderedCollections.SortedSet.new()\n    iex> OrderedCollections.SortedSet.to_list(set)\n    []\n\n    iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#module-examples"},{"type":"function","title":"OrderedCollections.SortedSet.add/2","doc":"Adds a value to the SortedSet.","ref":"OrderedCollections.SortedSet.html#add/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.add/2","doc":"iex> set = OrderedCollections.SortedSet.new([2, 3])\n    iex> set = OrderedCollections.SortedSet.add(set, 1)\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#add/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.delete/2","doc":"Deletes a value from the SortedSet.","ref":"OrderedCollections.SortedSet.html#delete/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.delete/2","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3])\n    iex> set = OrderedCollections.SortedSet.delete(set, 2)\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 3]","ref":"OrderedCollections.SortedSet.html#delete/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.difference/2","doc":"Returns a new SortedSet that contains elements in the first set that are not present in the second.","ref":"OrderedCollections.SortedSet.html#difference/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.difference/2","doc":"iex> set1 = OrderedCollections.SortedSet.new([1, 2, 3, 4, 5])\n    iex> set2 = OrderedCollections.SortedSet.new([2, 4])\n    iex> OrderedCollections.SortedSet.difference(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 3, 5]","ref":"OrderedCollections.SortedSet.html#difference/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.max/1","doc":"Returns the maximum element of the SortedSet.","ref":"OrderedCollections.SortedSet.html#max/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.max/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.max(set)\n    3","ref":"OrderedCollections.SortedSet.html#max/1-examples"},{"type":"function","title":"OrderedCollections.SortedSet.member?/2","doc":"Checks if a value is a member of the SortedSet.","ref":"OrderedCollections.SortedSet.html#member?/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.member?/2","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3])\n    iex> OrderedCollections.SortedSet.member?(set, 2)\n    true\n    iex> OrderedCollections.SortedSet.member?(set, 4)\n    false","ref":"OrderedCollections.SortedSet.html#member?/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.min/1","doc":"Returns the minimum element of the SortedSet.","ref":"OrderedCollections.SortedSet.html#min/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.min/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.min(set)\n    1","ref":"OrderedCollections.SortedSet.html#min/1-examples"},{"type":"function","title":"OrderedCollections.SortedSet.new/0","doc":"Creates a new empty SortedSet.","ref":"OrderedCollections.SortedSet.html#new/0"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.new/0","doc":"iex> set = OrderedCollections.SortedSet.new()\n    iex> OrderedCollections.SortedSet.to_list(set)\n    []","ref":"OrderedCollections.SortedSet.html#new/0-examples"},{"type":"function","title":"OrderedCollections.SortedSet.new/1","doc":"Creates a new SortedSet from a list.","ref":"OrderedCollections.SortedSet.html#new/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.new/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#new/1-examples"},{"type":"type","title":"OrderedCollections.SortedSet.non_empty_set/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:non_empty_set/0"},{"type":"type","title":"OrderedCollections.SortedSet.non_empty_t/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:non_empty_t/0"},{"type":"function","title":"OrderedCollections.SortedSet.range/3","doc":"Returns a list of elements in the SortedSet that fall within the given range (inclusive).","ref":"OrderedCollections.SortedSet.html#range/3"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.range/3","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3, 4, 5])\n    iex> OrderedCollections.SortedSet.range(set, 2, 4)\n    [2, 3, 4]","ref":"OrderedCollections.SortedSet.html#range/3-examples"},{"type":"opaque","title":"OrderedCollections.SortedSet.t/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:t/0"},{"type":"function","title":"OrderedCollections.SortedSet.to_list/1","doc":"Converts the SortedSet into a list of elements in sorted order.","ref":"OrderedCollections.SortedSet.html#to_list/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.to_list/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#to_list/1-examples"},{"type":"function","title":"OrderedCollections.SortedSet.union/2","doc":"Returns a new SortedSet that is the union of two SortedSets.","ref":"OrderedCollections.SortedSet.html#union/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.union/2","doc":"iex> set1 = OrderedCollections.SortedSet.new([1, 3, 5])\n    iex> set2 = OrderedCollections.SortedSet.new([2, 3, 4])\n    iex> OrderedCollections.SortedSet.union(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 2, 3, 4, 5]","ref":"OrderedCollections.SortedSet.html#union/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}